@@ -1,5 +1,5 @@
 if (opts.navigator_platform) {
     Object.defineProperty(Object.getPrototypeOf(navigator), 'platform', {
-        get: () => 'iPhone',
+        get: () => opts.navigator_platform,
     })
 }
\ No newline at end of file
